%global srcname oauth2client
%global sum Python client library for OAuth 2.0
# Share doc between python- and python3-
%global _docdir_fmt %{name}

%global py3_prefix python%{python3_pkgversion}

Name:           python-%{srcname}
Version:        4.0.0
Release:        3%{?dist}
Summary:        %{sum}

Group:          Development/Languages
License:        ASL 2.0
URL:            https://github.com/google/%{srcname}
Source0:        https://github.com/google/%{srcname}/archive/v%{version}.tar.gz#/%{srcname}-%{version}.tar.gz
Patch0:         docs-build-fix.patch

BuildArch:      noarch
BuildRequires:  python2-devel
# Needed for docs build
BuildRequires:  pyOpenSSL
BuildRequires:  python-crypto
BuildRequires:  python-django
BuildRequires:  python-jsonpickle
BuildRequires:  python-flask
BuildRequires:  python-httplib2 >= 0.9.1
BuildRequires:  python-keyring
BuildRequires:  python-mock
BuildRequires:  python2-pyasn1 >= 0.1.7
BuildRequires:  python2-pyasn1-modules >= 0.0.5
BuildRequires:  python-rsa >= 3.1.4
BuildRequires:  python-six >= 1.6.1
BuildRequires:  python-sqlalchemy
BuildRequires:  python-webtest

BuildRequires:  pytest

%if 0%{?rhel} && 0%{?rhel} <= 7
BuildRequires:  python-setuptools
BuildRequires:  python-fasteners
%else
BuildRequires:  python2-setuptools
BuildRequires:  python2-fasteners
%endif

%if 0%{?fedora}
# RHEL 7 has too old a version of python-sphinx
BuildRequires:  python-sphinx > 1.3
BuildRequires:  python-sphinx_rtd_theme
%endif

BuildRequires:  %{py3_prefix}-devel
BuildRequires:  %{py3_prefix}-fasteners
BuildRequires:  %{py3_prefix}-flask
BuildRequires:  %{py3_prefix}-httplib2 >= 0.9.1
BuildRequires:  %{py3_prefix}-keyring
BuildRequires:  %{py3_prefix}-mock
BuildRequires:  %{py3_prefix}-pyasn1 >= 0.1.7
BuildRequires:  %{py3_prefix}-pyasn1-modules >= 0.0.5
BuildRequires:  %{py3_prefix}-pyOpenSSL
BuildRequires:  %{py3_prefix}-pytest
BuildRequires:  %{py3_prefix}-rsa >= 3.1.4
BuildRequires:  %{py3_prefix}-setuptools
BuildRequires:  %{py3_prefix}-sqlalchemy

%description
This is a python client module for accessing resources protected by OAuth 2.0

%package -n python2-%{srcname}
Summary:        %{sum}
%{?python_provide:%python_provide python2-%{srcname}}

Requires:       pyOpenSSL
Requires:       python-httplib2 >= 0.9.1
Requires:       python-keyring
Requires:       python2-pyasn1 >= 0.1.7
Requires:       python2-pyasn1-modules >= 0.0.5
Requires:       python-rsa >= 3.1.4


%if 0%{?rhel} && 0%{?rhel} <= 7
Requires:       python-fasteners
Requires:       python-six >= 1.6.1
%else
Requires:       python2-fasteners
Requires:       python2-six >= 1.6.1
%endif

%description -n python2-%{srcname}
This is a python client module for accessing resources protected by OAuth 2.0


%package -n %{py3_prefix}-%{srcname}
Summary:        %{sum}
%{?python_provide:%python_provide python3-%{srcname}}

Requires:       %{py3_prefix}-pyOpenSSL
Requires:       %{py3_prefix}-fasteners
Requires:       %{py3_prefix}-httplib2 >= 0.9.1
Requires:       %{py3_prefix}-keyring
Requires:       %{py3_prefix}-pyasn1 >= 0.1.7
Requires:       %{py3_prefix}-pyasn1-modules >= 0.0.5
Requires:       %{py3_prefix}-rsa >= 3.1.4
Requires:       %{py3_prefix}-six >= 1.6.1

%description -n %{py3_prefix}-%{srcname}
This is a python client module for accessing resources protected by OAuth 2.0


%package doc
Summary:        Documentation for python oauth2client

%description doc
The python-oauth2client-doc package provides the documentation
for the package. Documentation is shipped in html format.

%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1 -b .doc

# We do not have the package for google.appengine support
# This is removed because it breaks the docs build otherwise
rm -f docs/source/oauth2client.contrib.appengine.rst oauth2client/appengine.py


%build
%py2_build
%if 0%{?fedora}
export PYTHONPATH=`pwd`
pushd docs
# Not running with smp_flags as sometimes sphinx fails when run
# with parallel make
make html
popd
unset PYTHONPATH
rm -vr docs/_build/html/_sources
rm -vr docs/_build/html/_static/fonts
rm -v docs/_build/html/{.buildinfo,objects.inv}
%endif
%py3_build


%install
%py2_install
%py3_install


%check
# Remove these to avoid py.test test collision.
rm -rf build/lib/tests/
# Remove these because django is weird on el7.
rm -rf tests/contrib/django_util
# Run the tests.
py.test
# excluded tests require Pycrypto (python3-crypto) which is not available in
# EPEL 7 (yet?).
py.test-%{python3_version} -x -vk "not test_jwt and not test__pycrypto_crypt"

# We remove tests currently, we will ship them eventually
# This is a bit of a hack until I package the test scripts in a separate package
rm -r $(find %{_buildrootdir} -type d -name 'tests')


%files -n python2-%{srcname}
%license LICENSE
%doc CHANGELOG.md CONTRIBUTING.md README.md 
%{python2_sitelib}/%{srcname}
%{python2_sitelib}/%{srcname}-%{version}-*.egg-info

%if 0%{?fedora}
%files doc
%doc docs/_build/html
%endif


%files -n %{py3_prefix}-%{srcname}
%license LICENSE 
%doc CHANGELOG.md CONTRIBUTING.md README.md 
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}*.egg-info


%changelog
* Wed Apr 29 2020 Felix Schwarz <fschwarz@fedoraproject.org> - 4.0.0-3
- add Python 3 subpackage for EPEL 7 (rhbz #1823057)

* Thu Mar 30 2017 Ralph Bean <rbean@redhat.com> - 4.0.0-2
- Compat for EPEL7.

* Wed Mar 29 2017 Ralph Bean <rbean@redhat.com> - 4.0.0-1
- new version

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Dec 27 2016 Michele Baldessari <michele@acksyn.org> - 3.0.0-3
- Fix python 3.6 breakage

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.0.0-2
- Rebuild for Python 3.6

* Thu Nov 10 2016 Michele Baldessari <michele@acksyn.org> - 3.0.0-1
- New upstream

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Sun May 22 2016 Michele Baldessari <michele@acksyn.org> - 2.1.0-1
- New upstream
* Tue Mar 08 2016 Michele Baldessari <michele@acksyn.org> - 2.0.1-1
- New upstream (NB: for now I am not shipping the tests, to be revised later)
* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild
* Thu Nov 26 2015 Michele Baldessari <michele@acksyn.org> - 1.5.2-2
- Remove dependency on sphinx-contrib-napoleon now that sphinx is at version >= 1.3
- Tighten versioned dependencies
- Update to latest python policy
* Thu Nov 19 2015 Michele Baldessari <michele@acksyn.org> - 1.5.2-1
- New upstream (BZ 1283443)
* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5
* Tue Oct 13 2015 Michele Baldessari <michele@acksyn.org> - 1.5.1-2
- Add versioned requires as per setup.py
* Thu Sep 17 2015 Michele Baldessari <michele@acksyn.org> - 1.5.1-1
- New upstream (BZ#1263881)
* Fri Sep 04 2015 Michele Baldessari <michele@acksyn.org> - 1.5.0-1
- New upstream (BZ#1259966)
* Sun Jul 12 2015 Michele Baldessari <michele@acksyn.org> - 1.4.12-1
- New upstream (BZ#1241304)
* Mon Jun 22 2015 Michele Baldessari <michele@acksyn.org> - 1.4.11-2
- Use -O1 for python3 as well
- Use python2 macros
- Remove the extra fonts from the -doc package
* Thu Jun 04 2015 Michele Baldessari <michele@acksyn.org> - 1.4.11-1
- Initial packaging
